summaryrefslogtreecommitdiffstats
path: root/kcontrol/background/bgdialog.h
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2022-07-16 14:35:39 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2022-07-18 00:12:20 +0900
commitab384ed0d51428fb99a8118466411b49f4865c37 (patch)
treeab9a5f36672e2315d642e2dcbdd91ac0727b07ba /kcontrol/background/bgdialog.h
parent90ea879f2be848f48846cf769cf3f1e03c4b9128 (diff)
downloadtdebase-ab384ed0d51428fb99a8118466411b49f4865c37.tar.gz
tdebase-ab384ed0d51428fb99a8118466411b49f4865c37.zip
Use Scale & Crop as default style for wallpaper.
Add more options to "Set as Background" menu in Konqueror. This resolves issue #280 and issue #281. Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> Signed-off-by: Mavridis Philippe <mavridisf@gmail.com> (cherry picked from commit 14bc816be9c921a6b004e0b0419e0c4c2f010b8c)
Diffstat (limited to 'kcontrol/background/bgdialog.h')
-rw-r--r--kcontrol/background/bgdialog.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/kcontrol/background/bgdialog.h b/kcontrol/background/bgdialog.h
index 6b33d8999..607118337 100644
--- a/kcontrol/background/bgdialog.h
+++ b/kcontrol/background/bgdialog.h
@@ -99,8 +99,11 @@ protected:
TQValueVector< TQPtrVector<KBackgroundRenderer> > m_renderer; // m_renderer[desk][screen]
TQMap<TQString,int> m_wallpaper;
TQStringList m_patterns;
- int m_slideShowRandom; // Remembers last Slide Show setting
- int m_wallpaperPos; // Remembers last wallpaper pos
+ int m_slideShowRandom; // Remembers last Slide Show setting
+ int m_wallpaperPos; // Remembers last wallpaper pos
+ int m_prevWallpaperPos; // Previous normal wallpaper pos
+ int m_prevTilePos; // Previous tile wallpaper pos
+ bool m_isTile; // Whether the wallpaper is a tile (800x600 or smaller)
BGMonitorArrangement * m_pMonitorArrangement;